@@ -1,11 +1,17 @@
+# TODO: provide a way to list repls.
+
+import os
+
 from requests import Session as HTTPSession
 from requests_html import HTMLSession
 
+# Environment variable configuration.
+REPLIT_DOMAIN = os.environ.get("REPLIT_DOMAIN", "repl.it")
+
+# Connection-pooling for HTTP requests.
 http = HTTPSession()
 html_http = HTMLSession()
 
-# TODO: provide a way to list repls.
-
 
 class ReplitUser:
     def __init__(self, username=None):
@@ -13,14 +19,27 @@ class ReplitUser:
         self.name = None
         self.bio = None
         self.avatar_url = None
-        self.languages = None
 
     def __repr__(self):
-        return f"<ReplitUser \"@{self.username}\">"
+        return f'<ReplitUser "@{self.username}">'
+
+    @property
+    def as_dict(self):
+        return {
+            "username": self.username,
+            "name": self.name,
+            "bio": self.bio,
+            "avatar_url": self.avatar_url,
+        }
+
+    @staticmethod
+    def _replit_url_from_username(username):
+        return f"https://{REPLIT_DOMAIN}/@{username}"
 
     @classmethod
     def from_username(_class, username):
         """Creates a new ReplitUser object from a given Repl.it profile name."""
+
         # TODO: catch non-existient users.
         url = _class._replit_url_from_username(username)
 
@@ -63,10 +82,11 @@ class ReplitUser:
         return avatar_url
 
 
-def get_user(username):
+def get_profile(username):
     """Creates a new ReplitUser object from a given Repl.it profile name."""
 
     return ReplitUser.from_username(username)
 
+
 # Syntax suagar.
 User = ReplitUser
